@@ -14,6 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import hashlib
 import logging
 import os
 import shutil
@@ -240,3 +241,55 @@ def parse_yaml(path):
     :returns: dict or list
     """
     return yaml.load(open(path))
+
+
+def calculate_sha(file_path, chunk_size=2 ** 20):
+    """Calculate file's checksum
+
+    :param str file_path: file path
+    :param int chunk_size: optional parameter, size of chunk
+    :returns: SHA1 string
+    """
+    sha = hashlib.sha1()
+
+    with open(file_path, 'rb') as f:
+        for chunk in iter(lambda: f.read(chunk_size), b''):
+            sha.update(chunk)
+
+    return sha.hexdigest()
+
+
+def calculate_checksums(dir_path):
+    """Calculates checksums of files in the directory
+
+    :param str dir_path: path to the directory
+    :returns: list of dicts, where 'checksum' is SHA1,
+              'file_path' is a relative path to the file
+    """
+    checksums = []
+    for root, _, files in os.walk(dir_path):
+        for file_path in files:
+            full_path = os.path.join(root, file_path)
+            rel_path = os.path.relpath(full_path, dir_path)
+
+            checksums.append({
+                'checksum': calculate_sha(full_path),
+                'file_path': rel_path})
+
+    return checksums
+
+
+def create_checksums_file(dir_path, checksums_file):
+    """Creates file with checksums
+
+    :param str dir_path: path to the directory for checksums calculation
+    :param str checksums_file: path to the file where checksums are saved
+    """
+    checksums = calculate_checksums(dir_path)
+    checksums_sorted = sorted(checksums, key=lambda c: c['file_path'])
+    checksum_lines = [
+        '{checksum} {file_path}\n'.format(**checksum)
+        for checksum in checksums_sorted]
+
+    with open(checksums_file, 'w') as f:
+        f.writelines(checksum_lines)
