@@ -69,17 +69,21 @@ SHELL_PARAMETERS = {
         'cmd': {'type': 'string'}}}
 
 
+TASK_BASE_PARAMETERS = {
+    '$schema': 'http://json-schema.org/draft-04/schema#',
+    'type': 'object',
+    'required': ['timeout'],
+    'properties': {
+        'timeout': POSITIVE_INTEGER}}
+
+
 TASK_SCHEMA = {
     '$schema': 'http://json-schema.org/draft-04/schema#',
     'type': 'object',
     'required': ['parameters', 'type', 'stage', 'role'],
     'properties': {
         'type': {'enum': ['puppet', 'shell']},
-        'parameters': {
-            'type': 'object',
-            'oneOf': [
-                PUPPET_PARAMETERS,
-                SHELL_PARAMETERS]},
+        'parameters': TASK_BASE_PARAMETERS,
         'stage': {'enum': ['post_deployment', 'pre_deployment']},
         'role': {
             'oneOf': [
@@ -93,16 +97,37 @@ TASKS_SCHEMA = {
     'items': TASK_SCHEMA}
 
 
-ENV_CONFIG_SCHEMA = {
+ATTR_ELEMENT_SCHEMA = {
+    '$schema': 'http://json-schema.org/draft-04/schema#',
+    'type': 'object',
+    'required': ['type', 'label', 'weight', 'value'],
+    'properties': {
+        'type': {'type': 'string'},
+        'weight': {'type': 'integer'},
+        'value': {'type': ['string', 'boolean']},
+        'label': {'type': 'string'},
+        'values': {'type': 'array', 'items':
+                   {'type': 'object',
+                    'required': ['data', 'label'],
+                    'properties': {
+                        'data': {'type': 'string'},
+                        'label': {'type': 'string'}}}}}}
+
+
+ATTR_META_SCHEMA = {
     '$schema': 'http://json-schema.org/draft-04/schema#',
     'type': 'object',
     'properties': {
-        'attributes': {
-            'type': 'object',
-            'additionalProperties': {
-                'type': 'object',
-                'properties': {
-                    'type': {'type': 'string'},
-                    'weight': {'type': 'integer'},
-                    'value': {'type': ['string', 'boolean']},
-                    'label': {'type': 'string'}}}}}}
+        'label': {'type': 'string'},
+        'weight': {'type': 'integer'},
+        'toggleable': {'type': 'boolean'},
+        'enabled': {'type': 'boolean'},
+        'restrictions': {
+            'type': 'array', 'items': {'type': ['string', 'object']}}}}
+
+
+ATTR_ROOT_SCHEMA = {
+    '$schema': 'http://json-schema.org/draft-04/schema#',
+    'type': 'object',
+    'properties': {
+        'attributes': {'type': 'object'}}}
